@@ -1,8 +1,8 @@
-import os
-import io
 import functools
+import io
 import logging
 import math
+import os
 
 logger = logging.getLogger("fsspec")
 
@@ -23,6 +23,8 @@ class BaseCache(object):
         How big this file is
     """
 
+    name = "none"
+
     def __init__(self, blocksize, fetcher, size):
         self.blocksize = blocksize
         self.fetcher = fetcher
@@ -47,6 +49,8 @@ class MMapCache(BaseCache):
     This cache method might only work on posix
     """
 
+    name = "mmap"
+
     def __init__(self, blocksize, fetcher, size, location=None, blocks=None):
         super().__init__(blocksize, fetcher, size)
         self.blocks = set() if blocks is None else blocks
@@ -54,8 +58,8 @@ class MMapCache(BaseCache):
         self.cache = self._makefile()
 
     def _makefile(self):
-        import tempfile
         import mmap
+        import tempfile
 
         if self.size == 0:
             return bytearray()
@@ -109,13 +113,15 @@ class MMapCache(BaseCache):
 
 
 class ReadAheadCache(BaseCache):
-    """ Cache which reads only when we get beyond a block of data
+    """Cache which reads only when we get beyond a block of data
 
     This is a much simpler version of BytesCache, and does not attempt to
     fill holes in the cache or keep fragments alive. It is best suited to
     many small reads in a sequential order (e.g., reading lines from a file).
     """
 
+    name = "readahead"
+
     def __init__(self, blocksize, fetcher, size):
         super().__init__(blocksize, fetcher, size)
         self.cache = b""
@@ -171,6 +177,8 @@ class BlockCache(BaseCache):
         use for this cache is then ``blocksize * maxblocks``.
     """
 
+    name = "blockcache"
+
     def __init__(self, blocksize, fetcher, size, maxblocks=32):
         super().__init__(blocksize, fetcher, size)
         self.nblocks = math.ceil(size / blocksize)
@@ -292,6 +300,8 @@ class BytesCache(BaseCache):
         we are more than a blocksize ahead of it.
     """
 
+    name = "bytes"
+
     def __init__(self, blocksize, fetcher, size, trim=True):
         super().__init__(blocksize, fetcher, size)
         self.cache = b""
@@ -364,10 +374,15 @@ class BytesCache(BaseCache):
         return len(self.cache)
 
 
-class AllBytes(object):
+class AllBytes(BaseCache):
     """Cache entire contents of the file"""
 
-    def __init__(self, data):
+    name = "all"
+
+    def __init__(self, blocksize=None, fetcher=None, size=None, data=None):
+        super().__init__(blocksize, fetcher, size)
+        if data is None:
+            data = self.fetcher(0, self.size)
         self.data = data
 
     def _fetch(self, start, end):
@@ -380,4 +395,5 @@ caches = {
     "bytes": BytesCache,
     "readahead": ReadAheadCache,
     "block": BlockCache,
+    "all": AllBytes,
 }
